@@ -110,6 +110,10 @@ public:
         E_FAILED_OUTBOUND_CONGESTION,
         E_FAILED_TIMEOUT_ON_RECV,
         E_FAILED_TIMEOUT_ON_SEND,
+        E_FAILED_TEST_DOESNT_MATCH,
+        E_FAILED_TEST_SHOULDNT_MATCH,
+        E_FAILED_STRCMP_DOESNT_MATCH,
+        E_FAILED_STRCMP_SHOULDNT_MATCH,
         E_OUT_OF_CALL_MSGS,
         E_WATCHDOG_MAJOR,
         E_WATCHDOG_MINOR,
@@ -146,6 +150,10 @@ public:
         CPT_C_FailedCallRegexpDoesntMatch,
         CPT_C_FailedCallRegexpShouldntMatch,
         CPT_C_FailedCallRegexpHdrNotFound,
+        CPT_C_FailedCallTestDoesntMatch,
+        CPT_C_FailedCallTestShouldntMatch,
+        CPT_C_FailedCallStrcmpDoesntMatch,
+        CPT_C_FailedCallStrcmpShouldntMatch,
         CPT_C_FailedOutboundCongestion,
         CPT_C_FailedTimeoutOnRecv,
         CPT_C_FailedTimeoutOnSend,
@@ -186,6 +194,10 @@ public:
         CPT_PD_FailedCallRegexpDoesntMatch,
         CPT_PD_FailedCallRegexpShouldntMatch,
         CPT_PD_FailedCallRegexpHdrNotFound,
+        CPT_PD_FailedCallTestDoesntMatch,
+        CPT_PD_FailedCallTestShouldntMatch,
+        CPT_PD_FailedCallStrcmpDoesntMatch,
+        CPT_PD_FailedCallStrcmpShouldntMatch,
         CPT_PD_FailedOutboundCongestion,
         CPT_PD_FailedTimeoutOnRecv,
         CPT_PD_FailedTimeoutOnSend,
@@ -227,6 +239,10 @@ public:
         CPT_PL_FailedCallRegexpDoesntMatch,
         CPT_PL_FailedCallRegexpShouldntMatch,
         CPT_PL_FailedCallRegexpHdrNotFound,
+        CPT_PL_FailedCallTestDoesntMatch,
+        CPT_PL_FailedCallTestShouldntMatch,
+        CPT_PL_FailedCallStrcmpDoesntMatch,
+        CPT_PL_FailedCallStrcmpShouldntMatch,
         CPT_PL_FailedOutboundCongestion,
         CPT_PL_FailedTimeoutOnRecv,
         CPT_PL_FailedTimeoutOnSend,
