@@ -29,10 +29,8 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
-extern "C" {
 #include "md5.h"
 #include "milenage.h"
-}
 #include "screen.hpp"
 #include "logger.hpp"
 #include "auth.hpp"
@@ -41,8 +39,6 @@ extern "C" {
 #define MD5_HASH_SIZE 16
 #define HASH_HEX_SIZE 2*MD5_HASH_SIZE
 
-extern char               *auth_uri;
-
 /* AKA */
 
 #define KLEN 16
