@@ -41,18 +41,17 @@
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
+
 #include "logger.hpp"
-#include "screen.hpp"
-#include "sipp.hpp"
 
 #define SIPP_ENDL "\r\n"
 
 #ifdef RTP_STREAM
-double last_rtpstream_rate_out= 0;
-double last_rtpstream_rate_in= 0;
+double last_rtpstream_rate_out = 0;
+double last_rtpstream_rate_in = 0;
 #endif
 
-extern void print_stats_in_file(FILE * f);
+void print_stats_in_file(FILE * f);
 
 bool do_hide = true;
 bool show_index = false;
@@ -263,7 +262,7 @@ void print_statistics(int last)
             print_stats_in_file(stdout);
             break;
         }
-        print_bottom_line(stdout,last);
+        print_bottom_line(stdout, last);
         if (!last && screen_last_error[0]) {
             char *errstart = screen_last_error;
             int colonsleft = 3;/* We want to skip the time. */
@@ -445,38 +444,38 @@ void print_stats_in_file(FILE * f)
     }
 #endif
 #ifdef RTP_STREAM
-  /* if we have rtp stream thread running */
-  if (rtpstream_numthreads) {
-    unsigned long TempBytes;
-    unsigned long last_tick= clock_tick;
-    /* Saved clock_tick to last_tick and use that in calcs since clock tick */
-    /* can change during calculations.                                      */
-    if (last_tick-last_report_time) {
-      TempBytes= rtpstream_bytes_out;
-      /* Calculate integer and fraction parts of rtp bandwidth; this value
-       * will be saved and reused in the case where last_tick==last_report_time
-       */
-      last_rtpstream_rate_out= ((double)TempBytes)/(last_tick-last_report_time);
-      /* Potential race condition betwen multiple threads updating the
-       * rtpstream_bytes value. We subtract the saved TempBytes value
-       * rather than setting it to zero to minimise the chances of missing
-       * an update to rtpstream_bytes [update between printing stats and
-       * zeroing the counter]. Ideally we would atomically subtract
-       * TempBytes from rtpstream_bytes.
-       */
-      rtpstream_bytes_out-= TempBytes;
-      TempBytes= rtpstream_bytes_in;
-      last_rtpstream_rate_in= ((double)TempBytes)/(last_tick-last_report_time);
-      rtpstream_bytes_in-= TempBytes;
-    }
-    sprintf(temp_str, "%lu Total RTP pckts sent",rtpstream_pckts);
-    fprintf(f,"  %-38s %.3f kB/s RTP OUT" SIPP_ENDL,
-              temp_str,last_rtpstream_rate_out);
+    /* if we have rtp stream thread running */
+    if (rtpstream_numthreads) {
+        unsigned long tempbytes;
+        unsigned long last_tick = clock_tick;
+        /* Saved clock_tick to last_tick and use that in calcs since clock tick */
+        /* can change during calculations.                                      */
+        if (last_tick - last_report_time) {
+            tempbytes = rtpstream_bytes_out;
+            /* Calculate integer and fraction parts of rtp bandwidth; this value
+             * will be saved and reused in the case where last_tick==last_report_time
+             */
+            last_rtpstream_rate_out = ((double)tempbytes) / (last_tick - last_report_time);
+            /* Potential race condition betwen multiple threads updating the
+             * rtpstream_bytes value. We subtract the saved tempbytes value
+             * rather than setting it to zero to minimise the chances of missing
+             * an update to rtpstream_bytes [update between printing stats and
+             * zeroing the counter]. Ideally we would atomically subtract
+             * tempbytes from rtpstream_bytes.
+             */
+            rtpstream_bytes_out -= tempbytes;
+            tempbytes = rtpstream_bytes_in;
+            last_rtpstream_rate_in = ((double)tempbytes) / (last_tick - last_report_time);
+            rtpstream_bytes_in -= tempbytes;
+        }
+        sprintf(temp_str, "%lu Total RTP pckts sent", rtpstream_pckts);
+        fprintf(f,"  %-38s %.3f kB/s RTP OUT" SIPP_ENDL,
+                temp_str, last_rtpstream_rate_out);
 
-    sprintf(temp_str, "%lu RTP sending threads active",rtpstream_numthreads);
-    fprintf(f,"  %-38s %.3f kB/s RTP IN" SIPP_ENDL,
-              temp_str,last_rtpstream_rate_in);
-  }
+        sprintf(temp_str, "%lu RTP sending threads active", rtpstream_numthreads);
+        fprintf(f,"  %-38s %.3f kB/s RTP IN" SIPP_ENDL,
+                temp_str, last_rtpstream_rate_in);
+    }
 #endif
 
     /* 5th line, RTP echo statistics */
@@ -653,7 +652,7 @@ void print_stats_in_file(FILE * f)
                     "",
                     "");
         } else {
-            ERROR("Scenario command not implemented in display\n");
+            ERROR("Scenario command not implemented in display");
         }
 
         if(lose_packets && (curmsg -> nb_lost)) {
@@ -858,7 +857,7 @@ static void rotatef(struct logfile_info* lfi)
     char L_rotate_file_name [MAX_PATH];
 
     if (!lfi->fixedname) {
-        sprintf (lfi->file_name, "%s_%d_%s.log", scenario_file, getpid(), lfi->name);
+        sprintf (lfi->file_name, "%s_%ld_%s.log", scenario_file, (long) getpid(), lfi->name);
     }
 
     if (ringbuffer_files > 0) {
@@ -868,13 +867,13 @@ static void rotatef(struct logfile_info* lfi)
         /* We need to rotate away an existing file. */
         if (lfi->nfiles == ringbuffer_files) {
             if ((lfi->ftimes)[0].n) {
-                sprintf(L_rotate_file_name, "%s_%d_%s_%lu.%d.log",
-                        scenario_file, getpid(), lfi->name,
+                sprintf(L_rotate_file_name, "%s_%ld_%s_%lu.%d.log",
+                        scenario_file, (long) getpid(), lfi->name,
                         (unsigned long)(lfi->ftimes)[0].start,
                         (lfi->ftimes)[0].n);
             } else {
-                sprintf(L_rotate_file_name, "%s_%d_%s_%lu.log",
-                        scenario_file, getpid(), lfi->name,
+                sprintf(L_rotate_file_name, "%s_%ld_%s_%lu.log",
+                        scenario_file, (long) getpid(), lfi->name,
                         (unsigned long)(lfi->ftimes)[0].start);
             }
             unlink(L_rotate_file_name);
@@ -889,13 +888,13 @@ static void rotatef(struct logfile_info* lfi)
                 (lfi->ftimes)[lfi->nfiles].n = (lfi->ftimes)[lfi->nfiles - 1].n + 1;
             }
             if ((lfi->ftimes)[lfi->nfiles].n) {
-                sprintf(L_rotate_file_name, "%s_%d_%s_%lu.%d.log",
-                        scenario_file, getpid(), lfi->name,
+                sprintf(L_rotate_file_name, "%s_%ld_%s_%lu.%d.log",
+                        scenario_file, (long) getpid(), lfi->name,
                         (unsigned long)(lfi->ftimes)[lfi->nfiles].start,
                         (lfi->ftimes)[lfi->nfiles].n);
             } else {
-                sprintf(L_rotate_file_name, "%s_%d_%s_%lu.log",
-                        scenario_file, getpid(), lfi->name,
+                sprintf(L_rotate_file_name, "%s_%ld_%s_%lu.log",
+                        scenario_file, (long) getpid(), lfi->name,
                         (unsigned long)(lfi->ftimes)[lfi->nfiles].start);
             }
             lfi->nfiles++;
@@ -952,84 +951,73 @@ void rotate_errorf()
     strcpy(screen_logfile, error_lfi.file_name);
 }
 
+static int _trace(struct logfile_info* lfi, const char* fmt, va_list ap)
+{
+    int ret = 0;
+    if(lfi->fptr) {
+        ret = vfprintf(lfi->fptr, fmt, ap);
+        fflush(lfi->fptr);
 
-/*#ifdef __cplusplus
-extern "C" {
-#endif
- * w
-*/
-    static int _trace(struct logfile_info* lfi, const char* fmt, va_list ap)
-    {
-        int ret = 0;
-        if(lfi->fptr) {
-            ret = vfprintf(lfi->fptr, fmt, ap);
-            fflush(lfi->fptr);
+        lfi->count += ret;
 
-            lfi->count += ret;
+        if (max_log_size && lfi->count > max_log_size) {
+            fclose(lfi->fptr);
+            lfi->fptr = NULL;
+        }
 
-            if (max_log_size && lfi->count > max_log_size) {
-                fclose(lfi->fptr);
-                lfi->fptr = NULL;
-            }
-
-            if (ringbuffer_size && lfi->count > ringbuffer_size) {
-                rotatef(lfi);
-                lfi->count = 0;
-            }
+        if (ringbuffer_size && lfi->count > ringbuffer_size) {
+            rotatef(lfi);
+            lfi->count = 0;
         }
-        return ret;
     }
+    return ret;
+}
 
 
-    int TRACE_MSG(const char *fmt, ...)
-    {
-        int ret;
-        va_list ap;
+int TRACE_MSG(const char *fmt, ...)
+{
+    int ret;
+    va_list ap;
 
-        va_start(ap, fmt);
-        ret = _trace(&message_lfi, fmt, ap);
-        va_end(ap);
+    va_start(ap, fmt);
+    ret = _trace(&message_lfi, fmt, ap);
+    va_end(ap);
 
-        return ret;
-    }
+    return ret;
+}
 
-    int TRACE_SHORTMSG(const char *fmt, ...)
-    {
-        int ret;
-        va_list ap;
+int TRACE_SHORTMSG(const char *fmt, ...)
+{
+    int ret;
+    va_list ap;
 
-        va_start(ap, fmt);
-        ret = _trace(&shortmessage_lfi, fmt, ap);
-        va_end(ap);
+    va_start(ap, fmt);
+    ret = _trace(&shortmessage_lfi, fmt, ap);
+    va_end(ap);
 
-        return ret;
-    }
+    return ret;
+}
 
-    int LOG_MSG(const char *fmt, ...)
-    {
-        int ret;
-        va_list ap;
+int LOG_MSG(const char *fmt, ...)
+{
+    int ret;
+    va_list ap;
 
-        va_start(ap, fmt);
-        ret = _trace(&log_lfi, fmt, ap);
-        va_end(ap);
+    va_start(ap, fmt);
+    ret = _trace(&log_lfi, fmt, ap);
+    va_end(ap);
 
-        return ret;
-    }
+    return ret;
+}
 
-    int TRACE_CALLDEBUG(const char *fmt, ...)
-    {
-        int ret;
-        va_list ap;
+int TRACE_CALLDEBUG(const char *fmt, ...)
+{
+    int ret;
+    va_list ap;
 
-        va_start(ap, fmt);
-        ret = _trace(&calldebug_lfi, fmt, ap);
-        va_end(ap);
+    va_start(ap, fmt);
+    ret = _trace(&calldebug_lfi, fmt, ap);
+    va_end(ap);
 
-        return ret;
-    }
-/*
-#ifdef __cplusplus
+    return ret;
 }
-#endif
-*/
