@@ -39,12 +39,8 @@
 #include <stdlib.h>
 #include <stdbool.h>
 #include <stdint.h>
-#if defined(__DARWIN) || defined(__CYGWIN) || defined(__FreeBSD__)
 #include <netinet/in.h>
-#endif
-#ifndef __CYGWIN
 #include <netinet/ip6.h>
-#endif
 #include <netinet/udp.h>
 #include <errno.h>
 #include <string.h>
@@ -61,7 +57,7 @@ extern volatile unsigned long rtp_bytes_pcap;
 extern bool media_ip_is_ipv6;
 
 inline void
-timerdiv (struct timeval *tvp, float div)
+timerdiv(struct timeval* tvp, float div)
 {
     double interval;
 
@@ -77,7 +73,7 @@ timerdiv (struct timeval *tvp, float div)
  * converts a float to a timeval structure
  */
 inline void
-float2timer (float time, struct timeval *tvp)
+float2timer(float time, struct timeval *tvp)
 {
     float n;
 
@@ -92,12 +88,12 @@ float2timer (float time, struct timeval *tvp)
 static char* find_file(const char* filename)
 {
     char *fullpath;
-    if (filename[0] == '/' || !scenario_path) {
+    if (filename[0] == '/' || !*scenario_path) {
         return strdup(filename);
     }
 
     fullpath = malloc(MAX_PATH);
-    snprintf(fullpath, MAX_PATH, "%s/%s", scenario_path, filename);
+    snprintf(fullpath, MAX_PATH, "%s%s", scenario_path, filename);
 
     if (access(fullpath, R_OK) < 0) {
         free(fullpath);
@@ -117,7 +113,7 @@ int parse_play_args(const char* filename, pcap_pkts* pkts)
     return 1;
 }
 
-void free_pcaps(pcap_pkts *pkts)
+void free_pcaps(pcap_pkts* pkts)
 {
     pcap_pkt *it;
     for (it = pkts->pkts; it != pkts->max; ++it) {
@@ -129,6 +125,12 @@ void free_pcaps(pcap_pkts *pkts)
     free(pkts);
 }
 
+int parse_dtmf_play_args(const char* buffer, pcap_pkts* pkts, uint16_t start_seq_no)
+{
+    pkts->file = strdup(buffer);
+    return prepare_dtmf(pkts->file, pkts, start_seq_no);
+}
+
 void hexdump(char *p, int s)
 {
     int i;
@@ -149,9 +151,21 @@ void send_packets_cleanup(void *arg)
     close(*sock);
 }
 
-int send_packets (play_args_t * play_args)
+void send_packets_pcap_cleanup(void* arg)
 {
-    int ret, sock, port_diff;
+    play_args_t* play_args = arg;
+
+    if (play_args->free_pcap_when_done) {
+        free(play_args->pcap);
+        play_args->pcap = NULL;
+    }
+}
+
+void send_packets(play_args_t* play_args)
+{
+    pthread_cleanup_push(send_packets_pcap_cleanup, ((void*)play_args));
+
+    int ret = 0, sock, port_diff;
     pcap_pkt *pkt_index, *pkt_max;
     uint16_t *from_port, *to_port;
     struct timeval didsleep = { 0, 0 };
@@ -165,7 +179,7 @@ int send_packets (play_args_t * play_args)
     struct sockaddr_in6 to6, from6;
     char buffer[PCAP_MAXPACKET];
     int temp_sum;
-    int len;
+    socklen_t len;
 
 #ifndef MSG_DONTWAIT
     int fd_flags;
@@ -175,25 +189,25 @@ int send_packets (play_args_t * play_args)
         sock = socket(PF_INET6, SOCK_RAW, IPPROTO_UDP);
         if (sock < 0) {
             ERROR("Can't create raw IPv6 socket (need to run as root?): %s", strerror(errno));
+            goto pop2;
         }
-        from_port = &(((struct sockaddr_in6 *)(void *) from )->sin6_port);
+        from_port = &(((struct sockaddr_in6 *)from)->sin6_port);
         len = sizeof(struct sockaddr_in6);
-        to_port = &(((struct sockaddr_in6 *)(void *) to )->sin6_port);
+        to_port = &(((struct sockaddr_in6 *)to)->sin6_port);
     } else {
         sock = socket(PF_INET, SOCK_RAW, IPPROTO_UDP);
-        from_port = &(((struct sockaddr_in *)(void *) from )->sin_port);
+        from_port = &(((struct sockaddr_in *)from)->sin_port);
         len = sizeof(struct sockaddr_in);
-        to_port = &(((struct sockaddr_in *)(void *) to )->sin_port);
+        to_port = &(((struct sockaddr_in *)to)->sin_port);
         if (sock < 0) {
             ERROR("Can't create raw IPv4 socket (need to run as root?): %s", strerror(errno));
-            return ret;
+            goto pop2;
         }
     }
 
-
-    if ((ret = bind(sock, (struct sockaddr *)(void *)from, len))) {
+    if ((ret = bind(sock, (struct sockaddr *)from, len))) {
         ERROR("Can't bind media raw socket");
-        return ret;
+        goto pop2;
     }
 
 #ifndef MSG_DONTWAIT
@@ -215,16 +229,13 @@ int send_packets (play_args_t * play_args)
         memcpy(&(from6.sin6_addr.s6_addr), &(((struct sockaddr_in6 *)(void *) from)->sin6_addr.s6_addr), sizeof(from6.sin6_addr.s6_addr));
     }
 
-
     /* Ensure the sender socket is closed when the thread exits - this
      * allows the thread to be cancelled cleanly.
      */
     pthread_cleanup_push(send_packets_cleanup, ((void *) &sock));
 
-
     while (pkt_index < pkt_max) {
         memcpy(udp, pkt_index->data, pkt_index->pktlen);
-#if defined(__HPUX) || defined(__DARWIN) || (defined __CYGWIN) || defined(__FreeBSD__)
         port_diff = ntohs(udp->uh_dport) - pkts->base;
         /* modify UDP ports */
         udp->uh_sport = htons(port_diff + ntohs(*from_port));
@@ -248,70 +259,50 @@ int send_packets (play_args_t * play_args)
 #else
         udp->uh_sum = temp_sum;
 #endif
-#else
-        port_diff = ntohs(udp->dest) - pkts->base;
-        /* modify UDP ports */
-        udp->source = htons(port_diff + ntohs(*from_port));
-        udp->dest = htons(port_diff + ntohs(*to_port));
-
-        if (!media_ip_is_ipv6) {
-            temp_sum = checksum_carry(
-                    pkt_index->partial_check +
-                    check((uint16_t *) &(((struct sockaddr_in *)(void *) from)->sin_addr.s_addr), 4) +
-                    check((uint16_t *) &(((struct sockaddr_in *)(void *) to)->sin_addr.s_addr), 4) +
-                    check((uint16_t *) &udp->source, 4));
-        } else {
-            temp_sum = checksum_carry(
-                    pkt_index->partial_check +
-                    check((uint16_t *) &(from6.sin6_addr.s6_addr), 16) +
-                    check((uint16_t *) &(to6.sin6_addr.s6_addr), 16) +
-                    check((uint16_t *) &udp->source, 4));
-        }
-        udp->check = temp_sum;
-#endif
 
         do_sleep ((struct timeval *) &pkt_index->ts, &last, &didsleep,
                   &start);
 #ifdef MSG_DONTWAIT
         if (!media_ip_is_ipv6) {
             ret = sendto(sock, buffer, pkt_index->pktlen, MSG_DONTWAIT,
-                         (struct sockaddr *)(void *) to, sizeof(struct sockaddr_in));
+                         (struct sockaddr *)to, sizeof(struct sockaddr_in));
         } else {
             ret = sendto(sock, buffer, pkt_index->pktlen, MSG_DONTWAIT,
-                         (struct sockaddr *)(void *) &to6, sizeof(struct sockaddr_in6));
+                         (struct sockaddr *)&to6, sizeof(struct sockaddr_in6));
         }
 #else
         if (!media_ip_is_ipv6) {
             ret = sendto(sock, buffer, pkt_index->pktlen, 0,
-                         (struct sockaddr *)(void *) to, sizeof(struct sockaddr_in));
+                         (struct sockaddr *)to, sizeof(struct sockaddr_in));
         } else {
             ret = sendto(sock, buffer, pkt_index->pktlen, 0,
-                         (struct sockaddr *)(void *) &to6, sizeof(struct sockaddr_in6));
+                         (struct sockaddr *)&to6, sizeof(struct sockaddr_in6));
         }
 #endif
         if (ret < 0) {
-            close(sock);
             WARNING("send_packets.c: sendto failed with error: %s", strerror(errno));
-            return( -1);
+            goto pop1;
         }
 
         rtp_pckts_pcap++;
         rtp_bytes_pcap += pkt_index->pktlen - sizeof(*udp);
-        memcpy (&last, &(pkt_index->ts), sizeof (struct timeval));
+        memcpy (&last, &(pkt_index->ts), sizeof(struct timeval));
         pkt_index++;
     }
 
     /* Closing the socket is handled by pthread_cleanup_push()/pthread_cleanup_pop() */
+pop1:
+    pthread_cleanup_pop(1);
+pop2:
     pthread_cleanup_pop(1);
-    return 0;
 }
 
 /*
  * Given the timestamp on the current packet and the last packet sent,
  * calculate the appropriate amount of time to sleep and do so.
  */
-void do_sleep (struct timeval *time, struct timeval *last,
-               struct timeval *didsleep, struct timeval *start)
+void do_sleep(struct timeval* time, struct timeval* last,
+              struct timeval* didsleep, struct timeval* start)
 {
     struct timeval nap, now, delta;
     struct timespec sleep;
