@@ -36,6 +36,16 @@
  */
 
 #include <dlfcn.h>
+#include <stdlib.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <unistd.h>
+
+#ifdef __APPLE__
+/* Provide OSX version of extern char **environ; */
+#include <crt_externs.h>
+#define environ (*_NSGetEnviron())
+#endif
 
 #define GLOBALS_FULL_DEFINITION
 #include "sipp.hpp"
@@ -47,8 +57,8 @@
 #include "config.h"
 #include "version.h"
 
-extern struct sipp_socket *ctrl_socket;
-extern struct sipp_socket *stdin_socket;
+extern SIPpSocket *ctrl_socket;
+extern SIPpSocket *stdin_socket;
 
 /* These could be local to main, but for the option processing table. */
 static int argiFileName;
@@ -138,7 +148,7 @@ struct sipp_option options_table[] = {
         "- ui: UDP with one socket per IP address. The IP addresses must be defined in the injection file.\n"
         "- t1: TCP with one socket,\n"
         "- tn: TCP with one socket per call,\n"
-#ifdef USE_OPENSSL
+#ifdef USE_TLS
         "- l1: TLS with one socket,\n"
         "- ln: TLS with one socket per call,\n"
 #endif
@@ -161,14 +171,18 @@ struct sipp_option options_table[] = {
     {"reconnect_sleep", "How long (in milliseconds) to sleep between the close and reconnect?", SIPP_OPTION_TIME_MS, &reset_sleep, 1},
     {"rsa", "Set the remote sending address to host:port for sending the messages.", SIPP_OPTION_RSA, NULL, 1},
 
-#ifdef USE_OPENSSL
+#ifdef USE_TLS
     {"tls_cert", "Set the name for TLS Certificate file. Default is 'cacert.pem", SIPP_OPTION_STRING, &tls_cert_name, 1},
     {"tls_key", "Set the name for TLS Private Key file. Default is 'cakey.pem'", SIPP_OPTION_STRING, &tls_key_name, 1},
+    {"tls_ca", "Set the name for TLS CA file. If not specified, X509 verification is not activated.", SIPP_OPTION_STRING, &tls_ca_name, 1},
     {"tls_crl", "Set the name for Certificate Revocation List file. If not specified, X509 CRL is not activated.", SIPP_OPTION_STRING, &tls_crl_name, 1},
+    {"tls_version", "Set the TLS protocol version to use (1.0, 1.1, 1.2) -- default is autonegotiate", SIPP_OPTION_FLOAT, &tls_version, 1},
 #else
     {"tls_cert", NULL, SIPP_OPTION_NEED_SSL, NULL, 1},
     {"tls_key", NULL, SIPP_OPTION_NEED_SSL, NULL, 1},
+    {"tls_ca", NULL, SIPP_OPTION_NEED_SSL, NULL, 1},
     {"tls_crl", NULL, SIPP_OPTION_NEED_SSL, NULL, 1},
+    {"tls_version", NULL, SIPP_OPTION_NEED_SSL, NULL, 1},
 #endif
 
 #ifdef USE_SCTP
@@ -243,7 +257,7 @@ struct sipp_option options_table[] = {
     {"inf", "Inject values from an external CSV file during calls into the scenarios.\n"
      "First line of this file say whether the data is to be read in sequence (SEQUENTIAL), random (RANDOM), or user (USER) order.\n"
      "Each line corresponds to one call and has one or more ';' delimited data fields. Those fields can be referred as [field0], [field1], ... in the xml scenario file.  Several CSV files can be used simultaneously (syntax: -inf f1.csv -inf f2.csv ...)", SIPP_OPTION_INPUT_FILE, NULL, 1},
-    {"infindex", "file field\nCreate an index of file using field.  For example -inf users.csv -infindex users.csv 0 creates an index on the first key.", SIPP_OPTION_INDEX_FILE, NULL, 1 },
+    {"infindex", "file field\nCreate an index of file using field.  For example -inf ../path/to/users.csv -infindex users.csv 0 creates an index on the first key.", SIPP_OPTION_INDEX_FILE, NULL, 1 },
     {"ip_field", "Set which field from the injection file contains the IP address from which the client will send its messages.\n"
      "If this option is omitted and the '-t ui' option is present, then field 0 is assumed.\n"
      "Use this option together with '-t ui'", SIPP_OPTION_INT, &peripfield, 1},
@@ -257,8 +271,6 @@ struct sipp_option options_table[] = {
     {"mb", "Set the RTP echo buffer size (default: 2048).", SIPP_OPTION_INT, &media_bufsize, 1},
     {"mp", "Set the local RTP echo port number. Default is 6000.", SIPP_OPTION_INT, &user_media_port, 1},
 #ifdef RTP_STREAM
-    {"min_rtp_port", "Minimum port number for RTP socket range.", SIPP_OPTION_INT, &min_rtp_port, 1},
-    {"max_rtp_port", "Maximum port number for RTP socket range.", SIPP_OPTION_INT, &max_rtp_port, 1},
     {"rtp_payload", "RTP default payload type.", SIPP_OPTION_INT, &rtp_default_payload, 1},
     {"rtp_threadtasks", "RTP number of playback tasks per thread.", SIPP_OPTION_INT, &rtp_tasks_per_thread, 1},
     {"rtp_buffsize", "Set the rtp socket send/receive buffer size.", SIPP_OPTION_INT, &rtp_buffsize, 1},
@@ -405,14 +417,10 @@ static struct sipp_option *find_option(const char* option) {
 extern unsigned pollnfds;
 #ifdef HAVE_EPOLL
 extern int epollfd;
-extern struct epoll_event   epollfiles[SIPP_MAXFDS];
 extern struct epoll_event*  epollevents;
-#else
-extern struct pollfd        pollfiles[SIPP_MAXFDS];
 #endif
-extern struct sipp_socket  *sockets[SIPP_MAXFDS];
 
-extern int pending_messages;
+extern SIPpSocket  *sockets[SIPP_MAXFDS];
 
 /************** Statistics display & User control *************/
 
@@ -429,244 +437,6 @@ static void sipp_sigusr2(int /* not used */)
     }
 }
 
-static void pollset_process(int wait)
-{
-    int rs; /* Number of times to execute recv().
-            For TCP with 1 socket per call:
-                no. of events returned by poll
-            For UDP and TCP with 1 global socket:
-                recv_count is a flag that stays up as
-                long as there's data to read */
-
-#ifndef HAVE_EPOLL
-    /* What index should we try reading from? */
-    static size_t read_index;
-
-    int loops = max_recv_loops;
-
-    // If not using epoll, we have a queue of pending messages to spin through.
-
-    if (read_index >= pollnfds) {
-        read_index = 0;
-    }
-
-    /* We need to process any messages that we have left over. */
-    while (pending_messages && loops > 0) {
-        getmilliseconds();
-        if (sockets[read_index]->ss_msglen) {
-            struct sockaddr_storage src;
-            char msg[SIPP_MAX_MSG_SIZE];
-            ssize_t len = read_message(sockets[read_index], msg, sizeof(msg), &src);
-            if (len > 0) {
-                process_message(sockets[read_index], msg, len, &src);
-            } else {
-                assert(0);
-            }
-            loops--;
-        }
-        read_index = (read_index + 1) % pollnfds;
-    }
-
-    /* Don't read more data if we still have some left over. */
-    if (pending_messages) {
-        return;
-    }
-#endif
-    /* Get socket events. */
-#ifdef HAVE_EPOLL
-    /* Ignore the wait parameter and always wait - when establishing TCP
-     * connections, the alternative is that we tight-loop. */
-    rs = epoll_wait(epollfd, epollevents, max_recv_loops, 1);
-    // If we're receiving as many epollevents as possible, flag CPU congestion
-    cpu_max = (rs > (max_recv_loops - 2));
-#else
-    rs = poll(pollfiles, pollnfds, wait ? 1 : 0);
-#endif
-    if (rs < 0 && errno == EINTR) {
-        return;
-    }
-
-    /* We need to flush all sockets and pull data into all of our buffers. */
-#ifdef HAVE_EPOLL
-    for (int event_idx = 0; event_idx < rs; event_idx++) {
-        int poll_idx = (int)epollevents[event_idx].data.u32;
-#else
-    for (size_t poll_idx = 0; rs > 0 && poll_idx < pollnfds; poll_idx++) {
-#endif
-        struct sipp_socket *sock = sockets[poll_idx];
-        int events = 0;
-        int ret = 0;
-
-        assert(sock);
-
-#ifdef HAVE_EPOLL
-        if (epollevents[event_idx].events & EPOLLOUT) {
-#else
-        if (pollfiles[poll_idx].revents & POLLOUT) {
-#endif
-
-#ifdef USE_SCTP
-            if (transport == T_SCTP && sock->sctpstate != SCTP_UP);
-            else
-#endif
-            {
-                /* We can flush this socket. */
-                TRACE_MSG("Exit problem event on socket %d \n", sock->ss_fd);
-#ifdef HAVE_EPOLL
-                epollfiles[poll_idx].events &= ~EPOLLOUT;
-                int rc = epoll_ctl(epollfd, EPOLL_CTL_MOD, sock->ss_fd, &epollfiles[poll_idx]);
-                if (rc == -1) {
-                    ERROR_NO("Failed to clear EPOLLOUT");
-                }
-#else
-                pollfiles[poll_idx].events &= ~POLLOUT;
-#endif
-                sock->ss_congested = false;
-
-                flush_socket(sock);
-                events++;
-            }
-        }
-
-#ifdef HAVE_EPOLL
-        if (epollevents[event_idx].events & EPOLLIN) {
-#else
-        if (pollfiles[poll_idx].revents & POLLIN) {
-#endif
-            /* We can empty this socket. */
-            if ((transport == T_TCP || transport == T_TLS || transport == T_SCTP) && sock == main_socket) {
-                struct sipp_socket *new_sock = sipp_accept_socket(sock);
-                if (!new_sock) {
-                    ERROR_NO("Accepting new TCP connection.\n");
-                }
-            } else if (sock == ctrl_socket) {
-                handle_ctrl_socket();
-            } else if (sock == stdin_socket) {
-                handle_stdin_socket();
-            } else if (sock == localTwinSippSocket) {
-                if (thirdPartyMode == MODE_3PCC_CONTROLLER_B) {
-                    twinSippSocket = sipp_accept_socket(sock);
-                    if (!twinSippMode) {
-                        ERROR_NO("Accepting new TCP connection on Twin SIPp Socket.\n");
-                    }
-                    twinSippSocket->ss_control = 1;
-                } else {
-                    /* 3pcc extended mode: open a local socket
-                       which will be used for reading the infos sent by this remote
-                       twin sipp instance (slave or master) */
-                    if (local_nb == MAX_LOCAL_TWIN_SOCKETS) {
-                        ERROR("Max number of twin instances reached\n");
-                    }
-
-                    struct sipp_socket *localSocket = sipp_accept_socket(sock);
-                    localSocket->ss_control = 1;
-                    local_sockets[local_nb] = localSocket;
-                    local_nb++;
-                    if (!peers_connected) {
-                        connect_to_all_peers();
-                    }
-                }
-            } else {
-                if ((ret = empty_socket(sock)) <= 0) {
-#ifdef USE_SCTP
-                    if (sock->ss_transport == T_SCTP && ret == -2);
-                    else
-#endif
-                    {
-                        ret = read_error(sock, ret);
-                        if (ret == 0) {
-                            /* If read_error() then the poll_idx now belongs
-                             * to the newest/last socket added to the sockets[].
-                             * Need to re-do the same poll_idx for the "new" socket.
-                             * We do this differently when using epoll. */
-#ifdef HAVE_EPOLL
-                            for (int event_idx2 = event_idx + 1; event_idx2 < rs; event_idx2++) {
-                                if (epollevents[event_idx2].data.u32 == pollnfds) {
-                                    epollevents[event_idx2].data.u32 = poll_idx;
-                                }
-                            }
-#else
-                            poll_idx--;
-                            events++;
-                            rs--;
-#endif
-                            continue;
-                        }
-                    }
-                }
-            }
-            events++;
-        }
-
-        /* Here the logic diverges; if we're using epoll, we want to stay in the
-         * for-each-socket loop and handle messages on that socket. If we're not using
-         * epoll, we want to wait until after that loop, and spin through our
-         * pending_messages queue again. */
-
-#ifdef HAVE_EPOLL
-        unsigned old_pollnfds = pollnfds;
-        getmilliseconds();
-        /* Keep processing messages until this socket is freed (changing the number of file descriptors) or we run out of messages. */
-        while ((pollnfds == old_pollnfds) &&
-                (sock->ss_msglen)) {
-            char msg[SIPP_MAX_MSG_SIZE];
-            struct sockaddr_storage src;
-            ssize_t len;
-
-            len = read_message(sock, msg, sizeof(msg), &src);
-            if (len > 0) {
-                process_message(sock, msg, len, &src);
-            } else {
-                assert(0);
-            }
-        }
-
-        if (pollnfds != old_pollnfds) {
-            /* Processing messages has changed the number of pollnfds, so update any remaining events */
-            for (int event_idx2 = event_idx + 1; event_idx2 < rs; event_idx2++) {
-                if (epollevents[event_idx2].data.u32 == pollnfds) {
-                    epollevents[event_idx2].data.u32 = poll_idx;
-                }
-            }
-        }
-#else
-
-        if (events) {
-            rs--;
-        }
-        pollfiles[poll_idx].revents = 0;
-#endif
-    }
-
-#ifndef HAVE_EPOLL
-    if (read_index >= pollnfds) {
-        read_index = 0;
-    }
-
-    /* We need to process any new messages that we read. */
-    while (pending_messages && (loops > 0)) {
-        getmilliseconds();
-
-        if (sockets[read_index]->ss_msglen) {
-            char msg[SIPP_MAX_MSG_SIZE];
-            struct sockaddr_storage src;
-            ssize_t len;
-
-            len = read_message(sockets[read_index], msg, sizeof(msg), &src);
-            if (len > 0) {
-                process_message(sockets[read_index], msg, len, &src);
-            } else {
-                assert(0);
-            }
-            loops--;
-        }
-        read_index = (read_index + 1) % pollnfds;
-    }
-
-    cpu_max = (loops <= 0);
-#endif
-}
-
 void timeout_alarm(int /*param*/)
 {
     if (timeout_error) {
@@ -678,11 +448,11 @@ void timeout_alarm(int /*param*/)
 
 /* Send loop & trafic generation*/
 
-static bool traffic_thread()
+static void traffic_thread()
 {
     /* create the file */
     char L_file_name[MAX_PATH];
-    sprintf(L_file_name, "%s_%d_screen.log", scenario_file, getpid());
+    sprintf(L_file_name, "%s_%ld_screen.log", scenario_file, (long) getpid());
 
     getmilliseconds();
 
@@ -720,7 +490,7 @@ static bool traffic_thread()
         }
 
         while (sockets_pending_reset.begin() != sockets_pending_reset.end()) {
-            reset_connection(*(sockets_pending_reset.begin()));
+            (*(sockets_pending_reset.begin()))->reset_connection();
             sockets_pending_reset.erase(sockets_pending_reset.begin());
         }
 
@@ -732,15 +502,22 @@ static bool traffic_thread()
                 /* Force exit: abort all calls */
                 abort_all_tasks();
             }
-            /* Quitting and no more openned calls, close all */
+            /* Quitting and no more opened calls, close all */
             if (!main_scenario->stats->GetStat(CStat::CPT_C_CurrentCall)) {
                 /* We can have calls that do not count towards our open-call count (e.g., dead calls). */
                 abort_all_tasks();
 #ifdef RTP_STREAM
                 rtpstream_shutdown();
 #endif
-                for (unsigned i = 0; i < pollnfds; i++) {
-                    sipp_close_socket(sockets[i]);
+                /* Reverse order shutdown, because deleting reorders the
+                 * sockets list. */
+                for (int i = pollnfds - 1; i >= 0; --i) {
+                    sockets[i]->close();
+                    if (sockets[i] == ctrl_socket) {
+                        ctrl_socket = NULL;
+                    } else if (sockets[i] == stdin_socket) {
+                        stdin_socket = NULL;
+                    }
                 }
 
                 screentask::report(true);
@@ -748,7 +525,7 @@ static bool traffic_thread()
                 if (useScreenf == 1) {
                     print_screens();
                 }
-                return false;
+                return;
             }
         }
 
@@ -784,9 +561,9 @@ static bool traffic_thread()
         task * last = NULL;
 
         task_list::iterator iter;
-        for(iter = running_tasks->begin(); iter != running_tasks->end(); iter++) {
+        for (iter = running_tasks->begin(); iter != running_tasks->end(); iter++) {
             if (last) {
-                last -> run();
+                last->run();
                 if (sockets_pending_reset.begin() != sockets_pending_reset.end()) {
                     last = NULL;
                     break;
@@ -798,19 +575,19 @@ static bool traffic_thread()
             }
         }
         if (last) {
-            last -> run();
+            last->run();
         }
         while (sockets_pending_reset.begin() != sockets_pending_reset.end()) {
-            reset_connection(*(sockets_pending_reset.begin()));
+            (*(sockets_pending_reset.begin()))->reset_connection();
             sockets_pending_reset.erase(sockets_pending_reset.begin());
         }
 
         /* Update the clock. */
         getmilliseconds();
         /* Receive incoming messages */
-        pollset_process(running_tasks->empty());
+        SIPpSocket::pollset_process(running_tasks->empty());
     }
-    return true;
+    assert(0);
 }
 
 /*************** RTP ECHO THREAD ***********************/
@@ -844,6 +621,11 @@ static void rtp_echo_thread(void* param)
                     errno);
             return;
         }
+#ifdef RTP_STREAM
+        if (!rtp_echo_state) {
+            continue;
+        }
+#endif
         ns = sendto(*(int*)param, msg, nr, 0,
                     (sockaddr*)&remote_rtp_addr, len);
 
@@ -948,11 +730,96 @@ static char* wrap(const char* in, int offset, int size)
     return out;
 }
 
+/* If stdout is a TTY, wrap stdout in a call to PAGER (generally less(1)).
+ * Returns a pid_t you'll have to pass to end_pager(). */
+static pid_t begin_pager() {
+    char pager[15] = "/usr/bin/pager";
+    char *argv[2] = {NULL, NULL};
+
+    int stdout_fd = fileno(stdout);
+    int read_write[2];
+    pid_t ret;
+
+    if (!isatty(stdout_fd)) {
+        return 0;
+    }
+
+    /* Get pager first, so we can bail if it's not there */
+    argv[0] = getenv("PAGER");
+    if (!argv[0]) {
+        argv[0] = pager; /* missing PAGER */
+    } else if (!*argv[0]) {
+        return 0; /* blank PAGER */
+    }
+
+    /* Should use euidaccess(3), but requires _GNU_SOURCE */
+    if (access(argv[0], X_OK) < 0) {
+        perror(argv[0]);
+        return 0;
+    }
+
+    /* Set up pipes and fork */
+    if (pipe(&read_write[0]) < 0) {
+        perror("pipe");
+        return 0;
+    }
+    if ((ret = fork()) < 0) {
+        perror("fork");
+        return 0;
+    }
+
+    /* Switch stdout FD in parent */
+    if (ret != 0) {
+        fflush(stdout);
+        close(stdout_fd);
+        close(read_write[0]);
+        if (dup2(read_write[1], stdout_fd) < 0) {
+            perror("dup2");
+        } else {
+            close(read_write[1]);
+        }
+        return ret;
+    }
+
+    /* Switch stdin FD and start pager in child */
+    if (setenv("LESS", "FRX", 1) < 0) {
+        perror("setenv");
+    }
+
+    close(STDIN_FILENO);
+    close(read_write[1]);
+    if (dup2(read_write[0], STDIN_FILENO) < 0) {
+        perror("dup2");
+    } else {
+        close(read_write[0]);
+    }
+    execve(argv[0], argv, environ);
+
+    /* This was not supposed to happen. Missing binary? */
+    perror("execve");
+    return 0;
+}
+
+/* Make sure we flush and close, or the child won't get all the data (and know
+ * when we're done). Wait for the child to exit first. */
+void end_pager(pid_t pager) {
+    fflush(stdout);
+    fclose(stdout);
+    while (pager != 0) {
+        int wstatus;
+        if (waitpid(pager, &wstatus, 0) == pager) {
+            pager = 0;
+        }
+    }
+}
+
 /* Help screen */
 static void help()
 {
     int i, max;
 
+    pid_t pager = begin_pager();
+
     printf
     ("\n"
      "Usage:\n"
@@ -1013,6 +880,8 @@ static void help()
         "   99: Normal exit without calls processed\n"
         "   -1: Fatal error\n"
         "   -2: Fatal error binding a socket\n");
+
+    end_pager(pager);
 }
 
 
@@ -1166,10 +1035,10 @@ static void manage_oversized_file(int signum)
     }
     managing = 1;
 
-    snprintf(L_file_name, MAX_PATH, "%s_%d_traces_oversized.log", scenario_file, getpid());
+    snprintf(L_file_name, MAX_PATH, "%s_%ld_traces_oversized.log", scenario_file, (long) getpid());
     f = fopen(L_file_name, "w");
     if (!f) {
-        ERROR_NO("Unable to open oversized log file\n");
+        ERROR_NO("Unable to open oversized log file");
     }
 
     GET_TIME(&currentTime);
@@ -1280,18 +1149,20 @@ static void set_scenario(const char* name)
     free(scenario_file);
     free(scenario_path);
 
-    const char* ext = strrchr(name, '.');
-    if (ext && strcmp(ext, ".xml") == 0) {
-        scenario_file = strndup(name, ext - name);
+    const char* sep = strrchr(name, '/');
+    if (sep) {
+        ++sep; // include slash
+        scenario_path = strndup(name, sep - name);
     } else {
-        scenario_file = strdup(name);
+        scenario_path = strdup("");
+        sep = name;
     }
 
-    const char* sep = strrchr(scenario_file, '/');
-    if (sep) {
-        scenario_path = strndup(scenario_file, sep - scenario_file);
+    const char* ext = strrchr(sep, '.');
+    if (ext && strcmp(ext, ".xml") == 0) {
+        scenario_file = strndup(sep, ext - sep);
     } else {
-        scenario_path = NULL;
+        scenario_file = strdup(sep);
     }
 }
 
@@ -1304,7 +1175,7 @@ static void set_scenario(const char* name)
 static int bind_rtp_sockets(struct sockaddr_storage* media_sa, int try_port, int last_attempt)
 {
     /* Create RTP sockets for audio and video. */
-    if ((media_socket_audio = socket(media_sa->ss_family, SOCK_DGRAM, 0)) == -1) {
+    if ((media_socket_audio = socket(media_sa->ss_family, SOCK_DGRAM, IPPROTO_UDP)) == -1) {
         ERROR_NO("Unable to create the audio RTP socket");
     }
 
@@ -1314,7 +1185,7 @@ static int bind_rtp_sockets(struct sockaddr_storage* media_sa, int try_port, int
         (_RCAST(struct sockaddr_in6*, media_sa))->sin6_port = htons(try_port);
     }
 
-    if (::bind(media_socket_audio, (sockaddr*)media_sa, SOCK_ADDR_SIZE(media_sa)) != 0) {
+    if (::bind(media_socket_audio, (sockaddr*)media_sa, socklen_from_addr(media_sa)) != 0) {
         if (last_attempt) {
             ERROR_NO("Unable to bind audio RTP socket (IP=%s, port=%d)", media_ip, try_port);
         }
@@ -1325,7 +1196,7 @@ static int bind_rtp_sockets(struct sockaddr_storage* media_sa, int try_port, int
 
     /* Create and bind the second/video socket to try_port+2 */
     /* (+1 is reserved for RTCP) */
-    if ((media_socket_video = socket(media_sa->ss_family, SOCK_DGRAM, 0)) == -1) {
+    if ((media_socket_video = socket(media_sa->ss_family, SOCK_DGRAM, IPPROTO_UDP)) == -1) {
         ERROR_NO("Unable to create the video RTP socket");
     }
 
@@ -1335,7 +1206,7 @@ static int bind_rtp_sockets(struct sockaddr_storage* media_sa, int try_port, int
         (_RCAST(struct sockaddr_in6*, media_sa))->sin6_port = htons(try_port + 2);
     }
 
-    if (::bind(media_socket_video, (sockaddr*)media_sa, SOCK_ADDR_SIZE(media_sa)) != 0) {
+    if (::bind(media_socket_video, (sockaddr*)media_sa, socklen_from_addr(media_sa)) != 0) {
         if (last_attempt) {
             ERROR_NO("Unable to bind video RTP socket (IP=%s, port=%d)",
                      media_ip, try_port + 2);
@@ -1379,7 +1250,7 @@ static void setup_media_sockets()
               "Use 'sipp -h' for details", media_ip);
     }
     memcpy(&media_sockaddr, local_addr->ai_addr,
-           SOCK_ADDR_SIZE(_RCAST(struct sockaddr_storage*, local_addr->ai_addr)));
+           socklen_from_addr(_RCAST(struct sockaddr_storage*, local_addr->ai_addr)));
     freeaddrinfo(local_addr);
 
     media_ip_is_ipv6 = (media_sockaddr.ss_family == AF_INET6);
@@ -1447,15 +1318,12 @@ int main(int argc, char *argv[])
     screen_set_exename("sipp");
 
     pid = getpid();
-    memset(local_ip, 0, 40);
+    memset(local_ip, 0, sizeof(local_ip));
 #ifdef USE_SCTP
-    memset(multihome_ip, 0, 40);
+    memset(multihome_ip, 0, sizeof(multihome_ip));
 #endif
-    memset(media_ip, 0, 40);
-    memset(control_ip, 0, 40);
-
-    /* Initialize the tolower table. */
-    init_tolower_table();
+    memset(media_ip, 0, sizeof(media_ip));
+    memset(control_ip, 0, sizeof(control_ip));
 
     /* Initialize our global variable structure. */
     globalVariables = new AllocVariableTable(NULL);
@@ -1491,7 +1359,7 @@ int main(int argc, char *argv[])
                 printf("\n %s.\n\n",
                        /* SIPp v1.2.3-TLS-PCAP */
                        "SIPp " SIPP_VERSION
-#ifdef USE_OPENSSL
+#ifdef USE_TLS
                        "-TLS"
 #endif
 #ifdef USE_SCTP
@@ -1647,9 +1515,9 @@ int main(int argc, char *argv[])
 #endif
                     break;
                 case 'l':
-#ifdef USE_OPENSSL
+#ifdef USE_TLS
                     transport = T_TLS;
-                    if (init_OpenSSL() != 1) {
+                    if (TLS_init() != 1) {
                         printf("OpenSSL Initialization problem\n");
                         exit(-1);
                     }
@@ -1659,7 +1527,7 @@ int main(int argc, char *argv[])
                     break;
                 case 'c':
                     if (strlen(comp_error)) {
-                        ERROR("No " COMP_PLUGGIN " plugin available:\n%s", comp_error);
+                        ERROR("No " COMP_PLUGGIN " plugin available: %s", comp_error);
                     }
                     transport = T_UDP;
                     compression = 1;
@@ -1681,7 +1549,7 @@ int main(int argc, char *argv[])
                 }
 
                 if (peripsocket && transport != T_UDP) {
-                    ERROR("You can only use a perip socket with UDP!\n");
+                    ERROR("You can only use a perip socket with UDP!");
                 }
                 break;
             case SIPP_OPTION_NEED_SCTP:
@@ -1756,10 +1624,10 @@ int main(int argc, char *argv[])
                 break;
             case SIPP_OPTION_3PCC:
                 if (slave_masterSet) {
-                    ERROR("-3PCC option is not compatible with -master and -slave options\n");
+                    ERROR("-3PCC option is not compatible with -master and -slave options");
                 }
                 if (extendedTwinSippMode) {
-                    ERROR("-3pcc and -slave_cfg options are not compatible\n");
+                    ERROR("-3pcc and -slave_cfg options are not compatible");
                 }
                 REQUIRE_ARG();
                 CHECK_PASS();
@@ -1770,7 +1638,9 @@ int main(int argc, char *argv[])
             case SIPP_OPTION_SCENARIO:
                 REQUIRE_ARG();
                 CHECK_PASS();
-                if (!strcmp(argv[argi - 1], "-sf")) {
+                if (main_scenario) {
+                    ERROR("Internal error, main_scenario already set");
+                } else if (!strcmp(argv[argi - 1], "-sf")) {
                     set_scenario(argv[argi]);
                     if (useLogf == 1) {
                         rotate_logfile();
@@ -1779,16 +1649,15 @@ int main(int argc, char *argv[])
                     main_scenario->stats->setFileName(scenario_file, ".csv");
                 } else if (!strcmp(argv[argi - 1], "-sn")) {
                     int i = find_scenario(argv[argi]);
-
-                    main_scenario = new scenario(0, i);
                     set_scenario(argv[argi]);
-                    main_scenario->stats->setFileName(argv[argi], ".csv");
+                    main_scenario = new scenario(0, i);
+                    main_scenario->stats->setFileName(scenario_file, ".csv");
                 } else if (!strcmp(argv[argi - 1], "-sd")) {
                     int i = find_scenario(argv[argi]);
                     fprintf(stdout, "%s", default_scenario[i]);
                     exit(EXIT_OTHER);
                 } else {
-                    ERROR("Internal error, I don't recognize %s as a scenario option\n", argv[argi] - 1);
+                    ERROR("Internal error, I don't recognize %s as a scenario option", argv[argi] - 1);
                 }
                 break;
             case SIPP_OPTION_OOC_SCENARIO:
@@ -1800,14 +1669,14 @@ int main(int argc, char *argv[])
                     int i = find_scenario(argv[argi]);
                     ooc_scenario = new scenario(0, i);
                 } else {
-                    ERROR("Internal error, I don't recognize %s as a scenario option\n", argv[argi] - 1);
+                    ERROR("Internal error, I don't recognize %s as a scenario option", argv[argi] - 1);
                 }
                 break;
             case SIPP_OPTION_SLAVE_CFG:
                 REQUIRE_ARG();
                 CHECK_PASS();
                 if (twinSippMode) {
-                    ERROR("-slave_cfg and -3pcc options are not compatible\n");
+                    ERROR("-slave_cfg and -3pcc options are not compatible");
                 }
                 extendedTwinSippMode = true;
                 slave_cfg_file = new char [strlen(argv[argi]) + 1];
@@ -1818,10 +1687,10 @@ int main(int argc, char *argv[])
                 REQUIRE_ARG();
                 CHECK_PASS();
                 if (slave_masterSet) {
-                    ERROR("-slave and -master options are not compatible\n");
+                    ERROR("-slave and -master options are not compatible");
                 }
                 if (twinSippMode) {
-                    ERROR("-master and -slave options are not compatible with -3PCC option\n");
+                    ERROR("-master and -slave options are not compatible with -3PCC option");
                 }
                 *((char**)option->data) = argv[argi];
                 slave_masterSet = true;
@@ -1839,37 +1708,17 @@ int main(int argc, char *argv[])
                 if (temp_remote_s_p != 0) {
                     remote_s_p = temp_remote_s_p;
                 }
-                struct addrinfo   hints;
-                struct addrinfo * local_addr;
 
                 printf("Resolving remote sending address %s...\n", remote_s_address);
 
-                memset((char*)&hints, 0, sizeof(hints));
-                hints.ai_flags  = AI_PASSIVE;
-                hints.ai_family = PF_UNSPEC;
-
                 /* FIXME: add DNS SRV support using liburli? */
-                if (getaddrinfo(remote_s_address,
-                                NULL,
-                                &hints,
-                                &local_addr) != 0) {
+                if (gai_getsockaddr(&remote_sending_sockaddr, remote_s_address, remote_s_p,
+                                    AI_PASSIVE, AF_UNSPEC) != 0) {
                     ERROR("Unknown remote host '%s'.\n"
                           "Use 'sipp -h' for details", remote_s_address);
                 }
 
-                memcpy(&remote_sending_sockaddr,
-                       local_addr->ai_addr,
-                       SOCK_ADDR_SIZE(
-                           _RCAST(struct sockaddr_storage *, local_addr->ai_addr)));
-
-                if (remote_sending_sockaddr.ss_family == AF_INET) {
-                    (_RCAST(struct sockaddr_in*, &remote_sending_sockaddr))->sin_port = htons(remote_s_p);
-                } else {
-                    (_RCAST(struct sockaddr_in6*, &remote_sending_sockaddr))->sin6_port = htons(remote_s_p);
-                }
                 use_remote_sending_addr = 1;
-
-                freeaddrinfo(local_addr);
                 break;
             }
             case SIPP_OPTION_RTCHECK:
@@ -1880,7 +1729,7 @@ int main(int argc, char *argv[])
                 } else if (!strcmp(argv[argi], "loose")) {
                     *((int*)option->data) = RTCHECK_LOOSE;
                 } else {
-                    ERROR("Unknown retransmission detection method: %s\n", argv[argi]);
+                    ERROR("Unknown retransmission detection method: %s", argv[argi]);
                 }
                 break;
             case SIPP_OPTION_TDMMAP: {
@@ -1935,7 +1784,7 @@ int main(int argc, char *argv[])
                         } else if (!strcmp(p, "pingreply")) {
                             mask = DEFAULT_BEHAVIOR_PINGREPLY;
                         } else {
-                            ERROR("Unknown default behavior: '%s'\n", token);
+                            ERROR("Unknown default behavior: '%s'", token);
                         }
                         switch(mode) {
                         case 0:
@@ -1995,7 +1844,7 @@ int main(int argc, char *argv[])
             }
             break;
             default:
-                ERROR("Internal error: I don't recognize the option type for %s\n", argv[argi]);
+                ERROR("Internal error: I don't recognize the option type for %s", argv[argi]);
             }
         }
     }
@@ -2006,7 +1855,7 @@ int main(int argc, char *argv[])
     }
 
     if ((extendedTwinSippMode && !slave_masterSet) || (!extendedTwinSippMode && slave_masterSet)) {
-        ERROR("-slave_cfg option must be used with -slave or -master option\n");
+        ERROR("-slave_cfg option must be used with -slave or -master option");
     }
 
     if (peripsocket) {
@@ -2024,13 +1873,17 @@ int main(int argc, char *argv[])
         lose_packets = 1;
     }
 
-    /* trace file setting */
+    /* If no scenario was selected, choose the uac one */
     if (scenario_file == NULL) {
-        set_scenario("sipp");
+        assert(main_scenario == NULL);
+        int i = find_scenario("uac");
+        set_scenario("uac");
+        main_scenario = new scenario(0, i);
+        main_scenario->stats->setFileName(scenario_file, ".csv");
     }
 
-#ifdef USE_OPENSSL
-    if ((transport == T_TLS) && (FI_init_ssl_context() != SSL_INIT_NORMAL)) {
+#ifdef USE_TLS
+    if ((transport == T_TLS) && (TLS_init_context() != TLS_INIT_NORMAL)) {
         ERROR("FI_init_ssl_context() failed");
     }
 #endif
@@ -2064,7 +1917,7 @@ int main(int argc, char *argv[])
 
     if (useCountf == 1) {
         char L_file_name [MAX_PATH];
-        sprintf(L_file_name, "%s_%d_counts.csv", scenario_file, getpid());
+        sprintf(L_file_name, "%s_%ld_counts.csv", scenario_file, (long) getpid());
         countf = fopen(L_file_name, "w");
         if (!countf) {
             ERROR("Unable to create '%s'", L_file_name);
@@ -2074,7 +1927,7 @@ int main(int argc, char *argv[])
 
     if (useErrorCodesf == 1) {
         char L_file_name [MAX_PATH];
-        sprintf(L_file_name, "%s_%d_error_codes.csv", scenario_file, getpid());
+        sprintf(L_file_name, "%s_%ld_error_codes.csv", scenario_file, (long) getpid());
         codesf = fopen(L_file_name, "w");
         if (!codesf) {
             ERROR("Unable to create '%s'", L_file_name);
@@ -2083,7 +1936,7 @@ int main(int argc, char *argv[])
 
 
     if (dumpInRtt == 1) {
-        main_scenario->stats->initRtt((char*)scenario_file, (char*)".csv",
+        main_scenario->stats->initRtt(scenario_file, ".csv",
                                       report_freq_dumpRtt);
     }
 
@@ -2118,12 +1971,6 @@ int main(int argc, char *argv[])
         }
     }
 
-    /* Load default scenario in case nothing was loaded */
-    if (!main_scenario) {
-        main_scenario = new scenario(0, 0);
-        main_scenario->stats->setFileName("uac", ".csv");
-        sprintf(scenario_file,"uac");
-    }
     /*
     if (!ooc_scenario) {
       ooc_scenario = new scenario(0, find_scenario("ooc_default"));
@@ -2194,7 +2041,7 @@ int main(int argc, char *argv[])
         break;
         default:
             // parent process - killing the parent - the child get the parent pid
-            printf("Background mode - PID=[%d]\n", l_pid);
+            printf("Background mode - PID=[%ld]\n", (long) l_pid);
             exit(EXIT_OTHER);
         }
     }
@@ -2254,12 +2101,7 @@ int main(int argc, char *argv[])
         }
     }
 
-    if (traffic_thread()) {
-        if (!nostdin) {
-            sipp_close_socket(stdin_socket);
-        }
-        sipp_close_socket(ctrl_socket);
-    }
+    traffic_thread();
 
     /* Cancel and join other threads. */
     if (pthread2_id) {
@@ -2280,10 +2122,7 @@ int main(int argc, char *argv[])
     free(epollevents);
 #endif
 
-    if (local_addr_storage) {
-        freeaddrinfo(local_addr_storage);
-    }
     free(scenario_file);
-
+    free(scenario_path);
     sipp_exit(EXIT_TEST_RES_UNKNOWN);
 }
